wallaroo.wallaroo_ml_ops_api_client.models.status_get_deployment_response_200_helm_item API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.status_get_deployment_response_200_helm_item

View Source

     1from typing import Any, Dict, List, Type, TypeVar
     2
     3import attr
     4
     5from ..models.status_get_deployment_response_200_helm_item_info import \
     6    StatusGetDeploymentResponse200HelmItemInfo
     7
     8T = TypeVar("T", bound="StatusGetDeploymentResponse200HelmItem")
     9
    10@attr.s(auto_attribs=True)
    11class StatusGetDeploymentResponse200HelmItem:
    12    """ Helm runner deployment status.
    13
    14    Attributes:
    15        info (StatusGetDeploymentResponse200HelmItemInfo):
    16    """
    17
    18    info: StatusGetDeploymentResponse200HelmItemInfo
    19    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    20
    21
    22    def to_dict(self) -> Dict[str, Any]:
    23        info = self.info.to_dict()
    24
    25
    26        field_dict: Dict[str, Any] = {}
    27        field_dict.update(self.additional_properties)
    28        field_dict.update({
    29            "info": info,
    30        })
    31
    32        return field_dict
    33
    34
    35
    36    @classmethod
    37    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    38        d = src_dict.copy()
    39        info = StatusGetDeploymentResponse200HelmItemInfo.from_dict(d.pop("info"))
    40
    41
    42
    43
    44        status_get_deployment_response_200_helm_item = cls(
    45            info=info,
    46        )
    47
    48        status_get_deployment_response_200_helm_item.additional_properties = d
    49        return status_get_deployment_response_200_helm_item
    50
    51    @property
    52    def additional_keys(self) -> List[str]:
    53        return list(self.additional_properties.keys())
    54
    55    def __getitem__(self, key: str) -> Any:
    56        return self.additional_properties[key]
    57
    58    def __setitem__(self, key: str, value: Any) -> None:
    59        self.additional_properties[key] = value
    60
    61    def __delitem__(self, key: str) -> None:
    62        del self.additional_properties[key]
    63
    64    def __contains__(self, key: str) -> bool:
    65        return key in self.additional_properties

@attr.s(auto_attribs=True)
class StatusGetDeploymentResponse200HelmItem: View Source

    11@attr.s(auto_attribs=True)
    12class StatusGetDeploymentResponse200HelmItem:
    13    """ Helm runner deployment status.
    14
    15    Attributes:
    16        info (StatusGetDeploymentResponse200HelmItemInfo):
    17    """
    18
    19    info: StatusGetDeploymentResponse200HelmItemInfo
    20    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    21
    22
    23    def to_dict(self) -> Dict[str, Any]:
    24        info = self.info.to_dict()
    25
    26
    27        field_dict: Dict[str, Any] = {}
    28        field_dict.update(self.additional_properties)
    29        field_dict.update({
    30            "info": info,
    31        })
    32
    33        return field_dict
    34
    35
    36
    37    @classmethod
    38    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    39        d = src_dict.copy()
    40        info = StatusGetDeploymentResponse200HelmItemInfo.from_dict(d.pop("info"))
    41
    42
    43
    44
    45        status_get_deployment_response_200_helm_item = cls(
    46            info=info,
    47        )
    48
    49        status_get_deployment_response_200_helm_item.additional_properties = d
    50        return status_get_deployment_response_200_helm_item
    51
    52    @property
    53    def additional_keys(self) -> List[str]:
    54        return list(self.additional_properties.keys())
    55
    56    def __getitem__(self, key: str) -> Any:
    57        return self.additional_properties[key]
    58
    59    def __setitem__(self, key: str, value: Any) -> None:
    60        self.additional_properties[key] = value
    61
    62    def __delitem__(self, key: str) -> None:
    63        del self.additional_properties[key]
    64
    65    def __contains__(self, key: str) -> bool:
    66        return key in self.additional_properties

Helm runner deployment status.

Attributes: info (StatusGetDeploymentResponse200HelmItemInfo):

StatusGetDeploymentResponse200HelmItem( info: wallaroo.wallaroo_ml_ops_api_client.models.status_get_deployment_response_200_helm_item_info.StatusGetDeploymentResponse200HelmItemInfo) View Source

    2def __init__(self, info):
    3    self.info = info
    4    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class StatusGetDeploymentResponse200HelmItem.

def to_dict(self) -> Dict[str, Any]: View Source

    23    def to_dict(self) -> Dict[str, Any]:
    24        info = self.info.to_dict()
    25
    26
    27        field_dict: Dict[str, Any] = {}
    28        field_dict.update(self.additional_properties)
    29        field_dict.update({
    30            "info": info,
    31        })
    32
    33        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    37    @classmethod
    38    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    39        d = src_dict.copy()
    40        info = StatusGetDeploymentResponse200HelmItemInfo.from_dict(d.pop("info"))
    41
    42
    43
    44
    45        status_get_deployment_response_200_helm_item = cls(
    46            info=info,
    47        )
    48
    49        status_get_deployment_response_200_helm_item.additional_properties = d
    50        return status_get_deployment_response_200_helm_item

additional_keys: List[str]